"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var objectUtils_1 = require("../utils/objectUtils");
var InputFileCollection = /** @class */ (function () {
    function InputFileCollection(files, mutateGlobResult) {
        this.files = files;
        this.filesToMutate = files.filter(function (file) { return mutateGlobResult.some(function (name) { return name === file.name; }); });
    }
    InputFileCollection.prototype.logFiles = function (log) {
        if (!this.files.length) {
            log.warn(objectUtils_1.normalizeWhiteSpaces("\n        No files selected. Please make sure you either run stryker a git repository context (and don't specify `files` in your stryker.conf.js file),\n        or specify the `files` property in your stryker config."));
        }
        else {
            if (this.filesToMutate.length) {
                log.info("Found " + this.filesToMutate.length + " of " + this.files.length + " file(s) to be mutated.");
            }
            else {
                log.warn("No files marked to be mutated, stryker will perform a dry-run without actually mutating anything.");
            }
            if (log.isDebugEnabled) {
                log.debug("All input files: " + JSON.stringify(this.files.map(function (file) { return file.name; }), null, 2));
                log.debug("Files to mutate: " + JSON.stringify(this.filesToMutate.map(function (file) { return file.name; }), null, 2));
            }
        }
    };
    return InputFileCollection;
}());
exports.default = InputFileCollection;
//# sourceMappingURL=InputFileCollection.js.map