"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var DashboardReporterClient_1 = require("./dashboard-reporter/DashboardReporterClient");
var objectUtils_1 = require("../utils/objectUtils");
var logging_1 = require("stryker-api/logging");
var Provider_1 = require("./ci/Provider");
var DashboardReporter = /** @class */ (function () {
    function DashboardReporter(_setting, dashboardReporterClient) {
        if (dashboardReporterClient === void 0) { dashboardReporterClient = new DashboardReporterClient_1.default(); }
        this.dashboardReporterClient = dashboardReporterClient;
        this.log = logging_1.getLogger(DashboardReporter.name);
        this.ciProvider = Provider_1.determineCIProvider();
    }
    DashboardReporter.prototype.readEnvironmentVariable = function (name) {
        var environmentVariable = objectUtils_1.getEnvironmentVariable(name);
        if (environmentVariable) {
            return environmentVariable;
        }
        else {
            this.log.warn("Missing environment variable " + name);
            return undefined;
        }
    };
    DashboardReporter.prototype.onScoreCalculated = function (ScoreResult) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var mutationScore, isPullRequest, repository, branch, apiKey;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        mutationScore = ScoreResult.mutationScore;
                        if (!(this.ciProvider !== undefined)) return [3 /*break*/, 5];
                        isPullRequest = this.ciProvider.isPullRequest();
                        if (!!isPullRequest) return [3 /*break*/, 3];
                        repository = this.ciProvider.determineRepository();
                        branch = this.ciProvider.determineBranch();
                        apiKey = this.readEnvironmentVariable('STRYKER_DASHBOARD_API_KEY');
                        if (!(repository && branch && apiKey)) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.dashboardReporterClient.postStrykerDashboardReport({
                                apiKey: apiKey,
                                branch: branch,
                                mutationScore: mutationScore,
                                repositorySlug: 'github.com/' + repository
                            })];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [3 /*break*/, 4];
                    case 3:
                        this.log.info('Dashboard report is not sent when building a pull request');
                        _a.label = 4;
                    case 4: return [3 /*break*/, 6];
                    case 5:
                        this.log.info('Dashboard report is not sent when not running on a buildserver');
                        _a.label = 6;
                    case 6: return [2 /*return*/];
                }
            });
        });
    };
    return DashboardReporter;
}());
exports.default = DashboardReporter;
//# sourceMappingURL=DashboardReporter.js.map