import CircleProvider from './CircleProvider';
import TravisProvider from './TravisProvider';
/**
 * Represents an object that can provide information about a CI/CD provider.
 */
export interface CIProvider {
    /** Returns whether Stryker is running on a pull request. */
    isPullRequest(): boolean;
    /** Returns the name of the Git branch of the project on which Stryker is running. */
    determineBranch(): string;
    /** Returns the name of the GitHub repository of the project on which Stryker is running. */
    determineRepository(): string;
}
/**
 * Return an approriate instance of CiProvider.
 * @returns An instance of CiProvider, or undefined if it appears Stryker is not running in a CI/CD environment.
 */
export declare function determineCIProvider(): CircleProvider | TravisProvider | undefined;
