"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var logging_1 = require("stryker-api/logging");
var HttpClient_1 = require("typed-rest-client/HttpClient");
var objectUtils_1 = require("../../utils/objectUtils");
var URL_STRYKER_DASHBOARD_REPORTER = 'https://dashboard.stryker-mutator.io/api/reports';
var DashboardReporterClient = /** @class */ (function () {
    function DashboardReporterClient(dashboardReporterClient) {
        if (dashboardReporterClient === void 0) { dashboardReporterClient = new HttpClient_1.HttpClient('stryker-dashboard-reporter'); }
        this.dashboardReporterClient = dashboardReporterClient;
        this.log = logging_1.getLogger(DashboardReporterClient.name);
    }
    DashboardReporterClient.prototype.postStrykerDashboardReport = function (report) {
        var _this = this;
        var _a;
        this.log.info("Posting report to " + URL_STRYKER_DASHBOARD_REPORTER);
        var reportString = JSON.stringify(report);
        this.log.debug('Posting data %s', reportString);
        return this.dashboardReporterClient.post(URL_STRYKER_DASHBOARD_REPORTER, reportString, (_a = {},
            _a['Content-Type'] = 'application/json',
            _a))
            .then(function (body) {
            var statusCode = body.message.statusCode;
            if (statusCode !== 201) {
                _this.log.error("Post to " + URL_STRYKER_DASHBOARD_REPORTER + " resulted in http status code: " + statusCode + ".");
            }
        })
            .catch(function (err) {
            _this.log.error("Unable to reach " + URL_STRYKER_DASHBOARD_REPORTER + ". Please check your internet connection.", objectUtils_1.errorToString(err));
        });
    };
    return DashboardReporterClient;
}());
exports.default = DashboardReporterClient;
//# sourceMappingURL=DashboardReporterClient.js.map